@@ -2,7 +2,6 @@ package chezmoi
 
 // FIXME implement externals in chezmoi source state format
 // FIXME implement external git repos
-// FIXME implement include and exclude entry type sets for externals
 
 import (
 	"bufio"
@@ -42,6 +41,7 @@ type ExternalType string
 const (
 	ExternalTypeArchive ExternalType = "archive"
 	ExternalTypeFile    ExternalType = "file"
+	ExternalTypeGitRepo ExternalType = "git-repo"
 )
 
 // An External is an external source.
@@ -50,14 +50,21 @@ type External struct {
 	Encrypted  bool         `json:"encrypted" toml:"encrypted" yaml:"encrypted"`
 	Exact      bool         `json:"exact" toml:"exact" yaml:"exact"`
 	Executable bool         `json:"executable" toml:"executable" yaml:"executable"`
-	Filter     struct {
+	Clone      struct {
+		Args []string `json:"args" toml:"args" yaml:"args"`
+	} `json:"clone" toml:"clone" yaml:"clone"`
+	Filter struct {
 		Command string   `json:"command" toml:"command" yaml:"command"`
 		Args    []string `json:"args" toml:"args" yaml:"args"`
 	} `json:"filter" toml:"filter" yaml:"filter"`
-	Format          ArchiveFormat `json:"format" toml:"format" yaml:"format"`
+	Format ArchiveFormat `json:"format" toml:"format" yaml:"format"`
+	Pull   struct {
+		Args []string `json:"args" toml:"args" yaml:"args"`
+	} `json:"pull" toml:"pull" yaml:"pull"`
 	RefreshPeriod   time.Duration `json:"refreshPeriod" toml:"refreshPeriod" yaml:"refreshPeriod"`
 	StripComponents int           `json:"stripComponents" toml:"stripComponents" yaml:"stripComponents"`
 	URL             string        `json:"url" toml:"url" yaml:"url"`
+	origin          string
 }
 
 // A externalCacheEntry is an external cache entry.
@@ -545,6 +552,10 @@ func (s *SourceState) Apply(
 		}
 	}
 
+	if !options.Include.IncludeExternals() && sourceStateEntry.External() {
+		return nil
+	}
+
 	destAbsPath := s.destDirAbsPath.Join(targetRelPath)
 	targetStateEntry, err := sourceStateEntry.TargetStateEntry(destSystem, destAbsPath)
 	if err != nil {
@@ -990,10 +1001,11 @@ func (s *SourceState) Read(ctx context.Context, options *ReadOptions) error {
 				if s.Ignore(destEntryRelPath) {
 					continue
 				}
-				allSourceStateEntries[destEntryRelPath] = append(allSourceStateEntries[destEntryRelPath], &SourceStateRemove{
+				sourceStateRemove := &SourceStateRemove{
 					sourceRelPath: sourceStateDir.sourceRelPath,
 					targetRelPath: destEntryRelPath,
-				})
+				}
+				allSourceStateEntries[destEntryRelPath] = append(allSourceStateEntries[destEntryRelPath], sourceStateRemove)
 			}
 		case errors.Is(err, fs.ErrNotExist):
 			// Do nothing.
@@ -1004,6 +1016,51 @@ func (s *SourceState) Read(ctx context.Context, options *ReadOptions) error {
 		}
 	}
 
+	// Generate SourceStateCommands for git-repo externals.
+	var gitRepoExternalRelPaths RelPaths
+	for externalRelPath, external := range s.externals {
+		if external.Type == ExternalTypeGitRepo {
+			gitRepoExternalRelPaths = append(gitRepoExternalRelPaths, externalRelPath)
+		}
+	}
+	sort.Sort(gitRepoExternalRelPaths)
+	for _, externalRelPath := range gitRepoExternalRelPaths {
+		external := s.externals[externalRelPath]
+		destAbsPath := s.destDirAbsPath.Join(externalRelPath)
+		switch _, err := s.system.Lstat(destAbsPath); {
+		case errors.Is(err, fs.ErrNotExist):
+			// FIXME add support for using builtin git
+			args := []string{"clone"}
+			args = append(args, external.Clone.Args...)
+			args = append(args, external.URL, destAbsPath.String())
+			cmd := exec.Command("git", args...)
+			sourceStateCommand := &SourceStateCommand{
+				cmd:           cmd,
+				external:      true,
+				origin:        external.origin,
+				forceRefresh:  options.RefreshExternals,
+				refreshPeriod: external.RefreshPeriod,
+			}
+			allSourceStateEntries[externalRelPath] = append(allSourceStateEntries[externalRelPath], sourceStateCommand)
+		case err != nil:
+			return err
+		default:
+			// FIXME add support for using builtin git
+			args := []string{"pull"}
+			args = append(args, external.Pull.Args...)
+			cmd := exec.Command("git", args...)
+			cmd.Dir = destAbsPath.String()
+			sourceStateCommand := &SourceStateCommand{
+				cmd:           cmd,
+				external:      true,
+				origin:        external.origin,
+				forceRefresh:  options.RefreshExternals,
+				refreshPeriod: external.RefreshPeriod,
+			}
+			allSourceStateEntries[externalRelPath] = append(allSourceStateEntries[externalRelPath], sourceStateCommand)
+		}
+	}
+
 	// Check for inconsistent source entries. Iterate over the target names in
 	// order so that any error is deterministic.
 	targetRelPaths := make(RelPaths, 0, len(allSourceStateEntries))
@@ -1110,6 +1167,7 @@ func (s *SourceState) addExternal(sourceAbsPath AbsPath) error {
 		if _, ok := s.externals[targetRelPath]; ok {
 			return fmt.Errorf("%s: duplicate externals", targetRelPath)
 		}
+		external.origin = sourceAbsPath.String()
 		s.externals[targetRelPath] = external
 	}
 	return nil
@@ -1742,6 +1800,8 @@ func (s *SourceState) readExternal(
 		return s.readExternalArchive(ctx, externalRelPath, parentSourceRelPath, external, options)
 	case ExternalTypeFile:
 		return s.readExternalFile(ctx, externalRelPath, parentSourceRelPath, external, options)
+	case ExternalTypeGitRepo:
+		return nil, nil
 	default:
 		return nil, fmt.Errorf("%s: unknown external type: %s", externalRelPath, external.Type)
 	}
@@ -1772,6 +1832,7 @@ func (s *SourceState) readExternalArchive(
 	}
 	sourceStateDir := &SourceStateDir{
 		Attr:          dirAttr,
+		external:      true,
 		origin:        external.URL,
 		sourceRelPath: parentSourceRelPath.Join(NewSourceRelPath(dirAttr.SourceName())),
 		targetStateEntry: &TargetStateDir{
@@ -1822,6 +1883,7 @@ func (s *SourceState) readExternalArchive(
 			}
 			sourceStateEntry = &SourceStateDir{
 				Attr:             dirAttr,
+				external:         true,
 				origin:           external.URL,
 				sourceRelPath:    parentSourceRelPath.Join(dirSourceRelPath, NewSourceRelPath(dirAttr.SourceName())),
 				targetStateEntry: targetStateEntry,
@@ -1849,6 +1911,7 @@ func (s *SourceState) readExternalArchive(
 			sourceStateEntry = &SourceStateFile{
 				lazyContents:     lazyContents,
 				Attr:             fileAttr,
+				external:         true,
 				origin:           external.URL,
 				sourceRelPath:    parentSourceRelPath.Join(dirSourceRelPath, sourceRelPath),
 				targetStateEntry: targetStateEntry,
@@ -1864,6 +1927,7 @@ func (s *SourceState) readExternalArchive(
 			}
 			sourceStateEntry = &SourceStateFile{
 				Attr:             fileAttr,
+				external:         true,
 				origin:           external.URL,
 				sourceRelPath:    parentSourceRelPath.Join(dirSourceRelPath, sourceRelPath),
 				targetStateEntry: targetStateEntry,
@@ -1898,6 +1962,7 @@ func (s *SourceState) readExternalFile(
 		perm:         fileAttr.perm() &^ s.umask,
 	}
 	sourceStateEntry := &SourceStateFile{
+		external:         true,
 		origin:           external.URL,
 		sourceRelPath:    parentSourceRelPath.Join(NewSourceRelPath(fileAttr.SourceName(s.encryption.EncryptedSuffix()))),
 		targetStateEntry: targetStateEntry,
