@@ -78,6 +78,7 @@ type Config struct {
 	Pager              string                          `mapstructure:"pager"`
 	PINEntry           pinEntryConfig                  `mapstructure:"pinentry"`
 	Safe               bool                            `mapstructure:"safe"`
+	ScriptTempDir      chezmoi.AbsPath                 `mapstructure:"scriptTempDir"`
 	SourceDirAbsPath   chezmoi.AbsPath                 `mapstructure:"sourceDir"`
 	Template           templateConfig                  `mapstructure:"template"`
 	Umask              fs.FileMode                     `mapstructure:"umask"`
@@ -1548,6 +1549,7 @@ func (c *Config) persistentPreRunRootE(cmd *cobra.Command, args []string) error
 
 	c.baseSystem = chezmoi.NewRealSystem(c.fileSystem,
 		chezmoi.RealSystemWithSafe(c.Safe),
+		chezmoi.RealSystemWithScriptTempDir(c.ScriptTempDir),
 	)
 	if c.debug {
 		systemLogger := c.logger.With().Str(logComponentKey, logComponentValueSystem).Logger()
@@ -2043,7 +2045,7 @@ func (c *Config) tempDir(key string) (chezmoi.AbsPath, error) {
 
 // useBuiltinAgeAutoFunc detects whether the builtin age should be used.
 func (c *Config) useBuiltinAgeAutoFunc() bool {
-	if _, err := exec.LookPath(c.Age.Command); err == nil {
+	if _, err := chezmoi.LookPath(c.Age.Command); err == nil {
 		return false
 	}
 	return true
@@ -2056,7 +2058,7 @@ func (c *Config) useBuiltinGitAutoFunc() bool {
 	if runtime.GOOS == "solaris" {
 		return false
 	}
-	if _, err := exec.LookPath(c.Git.Command); err == nil {
+	if _, err := chezmoi.LookPath(c.Git.Command); err == nil {
 		return false
 	}
 	return true
@@ -2083,7 +2085,7 @@ func (c *Config) writeOutputString(data string) error {
 
 func parseCommand(command string, args []string) (string, []string) {
 	// If command is found, then return it.
-	if path, err := exec.LookPath(command); err == nil {
+	if path, err := chezmoi.LookPath(command); err == nil {
 		return path, args
 	}
 
@@ -2091,7 +2093,7 @@ func parseCommand(command string, args []string) (string, []string) {
 	// is the editor and the rest are arguments.
 	components := whitespaceRx.Split(command, -1)
 	if len(components) > 1 {
-		if path, err := exec.LookPath(components[0]); err == nil {
+		if path, err := chezmoi.LookPath(components[0]); err == nil {
 			return path, append(components[1:], args...)
 		}
 	}
