@@ -1,5 +1,7 @@
 package cmd
 
+// FIXME add check for $TMPDIR mount options (specifically noexec)
+
 import (
 	"bytes"
 	"context"
@@ -16,6 +18,7 @@ import (
 	"text/tabwriter"
 
 	"github.com/coreos/go-semver/semver"
+	"github.com/google/go-github/v42/github"
 	"github.com/spf13/cobra"
 	"github.com/spf13/viper"
 	"github.com/twpayne/go-shell"
@@ -29,12 +32,12 @@ import (
 type checkResult int
 
 const (
+	checkResultFailed  checkResult = -2 // The check could not be completed.
 	checkResultSkipped checkResult = -1 // The check was skipped.
 	checkResultOK      checkResult = 0  // The check completed and did not find any problems.
 	checkResultInfo    checkResult = 1  // The check completed and found something interesting, but not a problem.
 	checkResultWarning checkResult = 2  // The check completed and found something that might indicate a problem.
 	checkResultError   checkResult = 3  // The check completed and found a definite problem.
-	checkResultFailed  checkResult = 4  // The check could not be completed.
 )
 
 // A check is an individual check.
@@ -44,12 +47,12 @@ type check interface {
 }
 
 var checkResultStr = map[checkResult]string{
+	checkResultFailed:  "failed",
 	checkResultSkipped: "skipped",
 	checkResultOK:      "ok",
 	checkResultInfo:    "info",
 	checkResultWarning: "warning",
 	checkResultError:   "error",
-	checkResultFailed:  "failed",
 }
 
 // An argsCheck checks that arguments for a binary.
@@ -388,7 +391,7 @@ func (c *binaryCheck) Run(system chezmoi.System, homeDirAbsPath chezmoi.AbsPath)
 	}
 
 	var pathAbsPath chezmoi.AbsPath
-	switch path, err := exec.LookPath(c.binaryname); {
+	switch path, err := chezmoi.LookPath(c.binaryname); {
 	case errors.Is(err, exec.ErrNotFound):
 		return c.ifNotExist, fmt.Sprintf("%s not found in $PATH", c.binaryname)
 	case err != nil:
@@ -534,15 +537,24 @@ func (c *latestVersionCheck) Name() string {
 
 func (c *latestVersionCheck) Run(system chezmoi.System, homeDirAbsPath chezmoi.AbsPath) (checkResult, string) {
 	if c.httpClientErr != nil {
-		return checkResultError, c.httpClientErr.Error()
+		return checkResultFailed, c.httpClientErr.Error()
 	}
 
 	ctx := context.Background()
 
 	gitHubClient := chezmoi.NewGitHubClient(ctx, c.httpClient)
 	rr, _, err := gitHubClient.Repositories.GetLatestRelease(ctx, c.owner, c.repo)
-	if err != nil {
-		return checkResultError, err.Error()
+	var rateLimitErr *github.RateLimitError
+	var abuseRateLimitErr *github.AbuseRateLimitError
+	switch {
+	case err == nil:
+		// Do nothing.
+	case errors.As(err, &rateLimitErr):
+		return checkResultFailed, "GitHub rate limit exceeded"
+	case errors.As(err, &abuseRateLimitErr):
+		return checkResultFailed, "GitHub abuse rate limit exceeded"
+	default:
+		return checkResultFailed, err.Error()
 	}
 
 	version, err := semver.NewVersion(strings.TrimPrefix(rr.GetName(), "v"))
@@ -588,13 +600,18 @@ func (c *suspiciousEntriesCheck) Name() string {
 }
 
 func (c *suspiciousEntriesCheck) Run(system chezmoi.System, homeDirAbsPath chezmoi.AbsPath) (checkResult, string) {
+	// FIXME include user-defined suffixes from age and gpg configs
+	encryptedSuffixes := []string{
+		defaultAgeEncryptionConfig.Suffix,
+		defaultGPGEncryptionConfig.Suffix,
+	}
 	// FIXME check that config file templates are in root
 	var suspiciousEntries []string
 	walkFunc := func(absPath chezmoi.AbsPath, fileInfo fs.FileInfo, err error) error {
 		if err != nil {
 			return err
 		}
-		if chezmoi.SuspiciousSourceDirEntry(absPath.Base(), fileInfo) {
+		if chezmoi.SuspiciousSourceDirEntry(absPath.Base(), fileInfo, encryptedSuffixes) {
 			suspiciousEntries = append(suspiciousEntries, absPath.String())
 		}
 		return nil
